<?xml version="1.0" encoding="UTF-8" ?>
<!--
	Created by James Moore on 2006-11-15.
-->

<xsl:stylesheet version="1.0"
	xmlns:html="http://www.w3.org/TR/REC-html40"
	xmlns:x="urn:schemas-microsoft-com:office:excel"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
	xmlns:c="urn:schemas-microsoft-com:office:component:spreadsheet"
	
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"

	xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
	exclude-result-prefixes="oo"
>

	<xsl:output encoding="UTF-8" indent="yes" method="xml" />

    <xsl:variable name="non-note-columns" select="oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes']" />
    <xsl:strip-space elements="*" />

	<xsl:variable name="outline-column-position">
	    <xsl:for-each select="$non-note-columns">
	      <xsl:if test="@is-outline-column = 'yes'">
	        <xsl:value-of select="position()"/>
	      </xsl:if>
	    </xsl:for-each>
	</xsl:variable>

	<xsl:template match="/">
		<Workbook 
			xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
			xmlns="urn:schemas-microsoft-com:office:spreadsheet"
			>
		
		 <OfficeDocumentSettings>
		  <AllowPNG/>
		 </OfficeDocumentSettings>
		 <ExcelWorkbook>
		  <Date1904/>
		  <AcceptLabelsInFormulas/>
		 </ExcelWorkbook>

         <xsl:call-template name="column-formats" />

         <xsl:call-template name="worksheet" />

	</Workbook>
	</xsl:template>

	<!-- style definitions -->
    <xsl:template name="column-formats" >
    	<xsl:element name="Styles" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
			<xsl:for-each select="$non-note-columns/oo:title">
				<xsl:element name="Style">
					<xsl:attribute name="ss:ID">
						<xsl:choose>
							<!-- the first column doesn't have a style ID for some reason -->
							<xsl:when test="position() = $outline-column-position">
								<xsl:text>Default</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>s</xsl:text>
						        <xsl:value-of select="position()"/>
							</xsl:otherwise>
						</xsl:choose>				
					</xsl:attribute>
			   </xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>

	<!-- wrapper for the table data -->
	<xsl:template name="worksheet">
		<xsl:element name="Worksheet" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
			<xsl:attribute name="ss:Name">Sheet1</xsl:attribute>
			<xsl:element name="Table">
				<xsl:apply-templates select="oo:outline/oo:columns"/>
		        <xsl:apply-templates select="oo:outline/oo:root/oo:item" />
			</xsl:element>
			  <WorksheetOptions xmlns="urn:schemas-microsoft-com:office:excel">
				<FreezePanes/>
				<FrozenNoSplit/>
				<SplitHorizontal>1</SplitHorizontal>
				<TopRowBottomPane>1</TopRowBottomPane>
				<ActivePane>2</ActivePane>
				<Panes>
					<Pane>
						<Number>3</Number>
					</Pane>
					<Pane>
						<Number>2</Number>
					</Pane>
				</Panes>
			</WorksheetOptions>
			
		</xsl:element>
	</xsl:template>

	<!-- column definitions -->
	<xsl:template match="oo:columns">
		<xsl:for-each select="$non-note-columns/oo:title">
			<xsl:element name="Column" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
				<xsl:attribute name="ss:AutoFitWidth">
					<xsl:text>0</xsl:text>
				</xsl:attribute>
				<xsl:if test="position() != $outline-column-position">
					<xsl:attribute name="ss:StyleID">
						<xsl:text>s</xsl:text>
						<xsl:value-of select="position()" />
					</xsl:attribute>
				</xsl:if>
			</xsl:element>
		</xsl:for-each>

		<!-- Emit the column titles as the first row of the spreadsheet. -->
		<xsl:element name="Row" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
			<xsl:for-each select="$non-note-columns/oo:title">
				<xsl:element name="Cell">
					<xsl:element name="Data">
						<xsl:attribute name="ss:Type">
							<xsl:text>String</xsl:text>
						</xsl:attribute>
						<xsl:apply-templates />
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
    </xsl:template> 

	<!-- emit the rows -->
    <xsl:template match="oo:item">
    	<xsl:element name="Row" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
	        <xsl:for-each select="oo:values/*">
				<xsl:element name="Cell">
					<xsl:apply-templates select="." />
					<!-- if we're in the outline column then add the note to the cell as a comment -->
		            <xsl:if test="position() = $outline-column-position">
						<xsl:apply-templates select="../../oo:note"/>
			        </xsl:if>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
        <xsl:apply-templates select="oo:children"/>
    </xsl:template>

	<xsl:template match="oo:values/oo:text | oo:enum | oo:checkbox | oo:date | oo:null">
		<xsl:element name="Data" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
			<xsl:attribute name="ss:Type">
				<xsl:text>String</xsl:text>
			</xsl:attribute>
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

<!-- we're not going to try to deal with number formats right now -->
	<xsl:template match="oo:number | oo:duration">
		<xsl:element name="Data" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
			<xsl:attribute name="ss:Type">
				<xsl:text>Number</xsl:text>
			</xsl:attribute>
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

    <xsl:template match="oo:note" >
    	<xsl:element name="Comment" xmlns="urn:schemas-microsoft-com:office:spreadsheet">
			<xsl:element name="Data">
				<xsl:apply-templates />
			</xsl:element>
		</xsl:element>
    </xsl:template>

    <xsl:template match="oo:text/oo:p">
        <xsl:apply-templates />
        <xsl:text> </xsl:text>
    </xsl:template>

    <xsl:template match="oo:cell" />
    <xsl:template match="oo:style" />

</xsl:stylesheet>
